@@ -213,6 +213,9 @@ class SoloClient:
     def wink(self,):
         self.send_data_hid(CTAPHID.WINK, b"")
 
+    def ping(self, data="pong"):
+        return self.send_data_hid(CTAPHID.PING, data)
+
     def reset(self,):
         self.ctap2.reset()
 
@@ -299,6 +302,10 @@ class SoloClient:
         of any updates.
         If you've started from a solo hacker, make you you've programmed a final/production build!
         """
+        if not self.is_solo_bootloader():
+            print("Device must be in bootloader mode.")
+            return False
+
         ret = self.exchange(
             SoloBootloader.disable, 0, b"\xcd\xde\xba\xaa"
         )  # magic number
@@ -306,7 +313,7 @@ class SoloClient:
             print("Failed to disable bootloader")
             return False
         time.sleep(0.1)
-        self.exchange(SoloBootloader.do_reboot)
+        self.exchange(SoloBootloader.reboot)
         return True
 
     def program_file(self, name):
